/** @format */
var _this = this;
var program = require('commander');
var commonAccess_1 = require('./commonAccess');
var path = require('path');
var os = require('os');
var inquirer = require('inquirer');
var fs = require('fs');
var yaml = require('js-yaml');
function isEqualArray(rightFormat, inputFormat) {
    if (!(rightFormat || inputFormat)) {
        return false;
    }
    if (rightFormat.length !== inputFormat.length) {
        return false;
    }
    rightFormat.forEach(function (item) {
        if (!inputFormat.includes(item)) {
            return false;
        }
    });
    return true;
}
var AddManager = (function () {
    function AddManager() {
        this.inputProviderAlias = '';
        this.isRightFormat = true;
        this.async = init(inputProviderAndAlisName, any, inputSecretCheck, any);
        this.globalFilePath = path.join(os.homedir(), '.s/access.yaml');
        this.inputFullData = {};
        this.context = program.args;
    }
    return AddManager;
})();
exports.AddManager = AddManager;
{
    if (program.args.length > 0) {
        throw Error('Configuration failed');
    }
    else if (inputProviderAndAlisName.Provider) {
        this.provider = String(inputProviderAndAlisName.Provider).toLocaleLowerCase();
        this.aliasName = String(inputProviderAndAlisName.AliasName || 'default').toLocaleLowerCase();
        if (commonAccess_1.providerArray.indexOf(this.provider) === -1) {
            throw Error("The cloud vendor[" + this.provider + "] was not found. [alibaba/aws/azure/baidu/google/huawei/tencent]");
        }
        this.inputSecretID = {};
        var inputSecretCheckKeys = Object.keys(inputSecretCheck); // 用户输入的秘钥对象的key
        // 正确秘钥形式
        var providerAccessFormatSecret = commonAccess_1.providerAccessFormat[this.provider];
        // 检查用户输入的秘钥的格式与对应云厂商的格式是否相同
        if (isEqualArray(providerAccessFormatSecret, inputSecretCheckKeys)) {
            for (var _i = 0; _i < inputSecretCheckKeys.length; _i++) {
                var item = inputSecretCheckKeys[_i];
                this.inputSecretID[item] = inputSecretCheck[item];
            }
        }
        else {
            throw new Error("Please Input Right Secret Format: [" + providerAccessFormatSecret + "]");
        }
    }
    else {
        await;
        this.inputLengthZero();
    }
    await;
    this.checkInputSecretID();
    this.inputProviderAlias = this.provider + "." + (this.aliasName || 'default');
    this.inputFullData[this.inputProviderAlias] = this.inputSecretID;
    this.writeData(this.globalFilePath, this.inputFullData);
}
output();
{
    console.log('');
    console.info("  Provider: " + commonAccess_1.providerObject[this.provider] + " (" + this.provider + ")");
    if (this.aliasName) {
        console.info("    Alias: " + this.aliasName);
    }
    // eslint-disable-next-line guard-for-in
    for (var item in this.inputSecretID) {
        console.info("    " + item + ": " + this.inputSecretID[item]);
    }
    console.log('');
}
// 用户输入参数为0的时候
async;
inputLengthZero(provider, any = undefined);
{
    if (!provider) {
        await;
        inquirer.prompt(commonAccess_1.checkProviderList).then(function (answers) {
            _this.provider = answers.provider;
        });
    }
    else {
        this.provider = provider.toLocaleLowerCase();
    }
    if (!commonAccess_1.providerArray.includes(this.provider)) {
        throw Error("The cloud vendor[" + this.provider + "] was not found. [alibaba/aws/azure/baidu/google/huawei/tencent]");
    }
    try {
        Object.keys(commonAccess_1.providerCollection).forEach(function (item) {
            if (item === _this.provider) {
                _this.promptList = commonAccess_1.providerCollection[item];
            }
        });
        this.promptList.push({
            type: 'input',
            message: 'Please create alias for key pair. If not, please enter to skip',
            name: 'aliasName',
            default: 'default'
        });
    }
    catch (err) {
        throw Error(err.message);
    }
    await;
    inquirer.prompt(this.promptList).then(function (answers) {
        _this.inputSecretID = answers;
    });
    Object.keys(this.inputSecretID).forEach(function (item) {
        if (item === 'aliasName') {
            _this.aliasName = _this.inputSecretID[item];
            delete _this.inputSecretID[item];
        }
    });
    this.inputProviderAlias = this.provider + "." + this.aliasName || 'default';
    return this.inputSecretID;
}
// 检查用户输入的输入的inputSecretID是否为空值
async;
checkInputSecretID();
{
    // eslint-disable-next-line guard-for-in
    for (var item in this.inputSecretID) {
        var isTrue = String(typeof this.inputSecretID[item]) === 'string';
        if (!this.inputSecretID[item] || !isTrue) {
            throw Error("The Provider[" + commonAccess_1.providerObject[this.provider] + "]: key[" + item + "] is required.");
        }
    }
}
async;
writeFileWay(filePath, string, text, ConfigMap);
{
    this.output();
    try {
        await;
        fs.writeFileSync(filePath, yaml.dump(text));
    }
    catch (err) {
        throw Error('Configuration failed');
    }
}
writeData(filePath, string, text, ConfigMap);
{
    var isExists = fs.existsSync(filePath);
    // 当前文件不存在
    if (!isExists) {
        this.writeFileWay(filePath, text);
    }
    else {
        var userInformation = yaml.safeLoad(fs.readFileSync(filePath, 'utf8'));
        // 文件存在，且不为空；
        // eslint-disable-next-line no-eq-null,eqeqeq
        if (userInformation != null) {
            var userProviderAlias = Object.keys(userInformation);
            var isExistProviderAlias = userProviderAlias.includes(this.inputProviderAlias);
            // 全局配置是否含有用户输入的provider.alias
            if (isExistProviderAlias) {
                throw Error("Provider + Alias already exists. You can set a different alias or modify it through: s config update -p " + this.provider + " -a " + (this.aliasName || 'default'));
            }
            else {
                try {
                    fs.appendFileSync(filePath, yaml.dump(text));
                    this.output();
                    console.info('Configuration successful');
                }
                catch (err) {
                    throw Error('Configuration failed');
                }
            }
        }
        else {
            this.writeFileWay(filePath, text);
        }
    }
}
